Addresses https://trac.macports.org/ticket/68716,
committed upstream https://github.com/OSGeo/gdal/commit/994e40dbbf3dfd58ad66de02d87070afafd8da88

--- cmake/template/cpl_config.h.in.orig
+++ cmake/template/cpl_config.h.in
@@ -175,6 +175,9 @@
 /* Define to 1 if you have the `sched_getaffinity' function. */
 #cmakedefine HAVE_SCHED_GETAFFINITY 1
 
+/* Define to 1 if you have the `std::shared_mutex' function. */
+#cmakedefine HAVE_SHARED_MUTEX 1
+
 /* Define to 1 if you have the `uselocale' function. */
 #cmakedefine HAVE_USELOCALE 1
 


--- cmake/helpers/configure.cmake.orig
+++ cmake/helpers/configure.cmake
@@ -359,6 +359,19 @@
     add_definitions(-DDONT_DEPRECATE_SPRINTF)
   endif ()
 
+  check_cxx_source_compiles(
+    "
+    #include <shared_mutex>
+    int main(int argc, const char * argv[]) {
+        std::shared_mutex smtx;
+        smtx.lock_shared();
+        smtx.unlock_shared();
+        return 0;
+    }
+    "
+    HAVE_SHARED_MUTEX
+  )
+
   check_include_file("linux/userfaultfd.h" HAVE_USERFAULTFD_H)
 endif ()


--- port/cpl_vsi_mem.cpp.orig
+++ port/cpl_vsi_mem.cpp
@@ -50,7 +50,7 @@
 
 #include <mutex>
 // c++17 or VS2017
-#if __cplusplus >= 201703L || _MSC_VER >= 1910
+#if defined(HAVE_SHARED_MUTEX) || _MSC_VER >= 1910
 #include <shared_mutex>
 #define CPL_SHARED_MUTEX_TYPE std::shared_mutex
 #define CPL_SHARED_LOCK std::shared_lock<std::shared_mutex>
